Documentation
¶
Index ¶
- func DefaultProfile() model.DocsReadProfile
- func DetectLayerForPath(profile model.DocsReadProfile, path string) string
- func GovernanceDocPath(root string) string
- func GovernanceReadinessSummary(status model.GovernanceStatus) string
- func IndexWorkspaceDocs(ctx context.Context, root string, matcher *workspace.IgnoreMatcher) ([]model.DocRecord, []model.DocEdge, []model.DocMention, []string, error)
- func IndexWorkspaceDocsWithProgress(ctx context.Context, root string, matcher *workspace.IgnoreMatcher, ...) ([]model.DocRecord, []model.DocEdge, []model.DocMention, []string, error)
- func IndexWorkspaceDocsWithSourcesWithProgress(ctx context.Context, root string, matcher *workspace.IgnoreMatcher, ...) ([]model.DocRecord, []model.DocEdge, []model.DocMention, []model.DocSourceBlock, ...)
- func InspectGovernance(root string, autoSync bool) model.GovernanceStatus
- func LoadProfile(root string) (model.DocsReadProfile, string, []string)
- func MatchFamily(question string, profile model.DocsReadProfile) string
- func ProfilePath(root string) string
- func QuestionTokens(question string) []string
- func Tier1CanonicalRoute(question string, profile model.DocsReadProfile, root string) (model.RouteCanonicalLane, []string)
- type Progress
- type ProgressFunc
- type RFFrontMatter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultProfile ¶
func DefaultProfile() model.DocsReadProfile
func DetectLayerForPath ¶ added in v0.3.0
func DetectLayerForPath(profile model.DocsReadProfile, path string) string
func GovernanceDocPath ¶ added in v0.3.0
func GovernanceReadinessSummary ¶ added in v0.3.0
func GovernanceReadinessSummary(status model.GovernanceStatus) string
func IndexWorkspaceDocs ¶
func IndexWorkspaceDocsWithProgress ¶ added in v0.3.0
func IndexWorkspaceDocsWithProgress(ctx context.Context, root string, matcher *workspace.IgnoreMatcher, progress ProgressFunc) ([]model.DocRecord, []model.DocEdge, []model.DocMention, []string, error)
func IndexWorkspaceDocsWithSourcesWithProgress ¶ added in v0.3.0
func IndexWorkspaceDocsWithSourcesWithProgress(ctx context.Context, root string, matcher *workspace.IgnoreMatcher, progress ProgressFunc) ([]model.DocRecord, []model.DocEdge, []model.DocMention, []model.DocSourceBlock, []model.DocSourceRecord, []string, error)
func InspectGovernance ¶ added in v0.3.0
func InspectGovernance(root string, autoSync bool) model.GovernanceStatus
func LoadProfile ¶
func LoadProfile(root string) (model.DocsReadProfile, string, []string)
func MatchFamily ¶
func MatchFamily(question string, profile model.DocsReadProfile) string
func ProfilePath ¶
func QuestionTokens ¶
func Tier1CanonicalRoute ¶ added in v0.3.0
func Tier1CanonicalRoute(question string, profile model.DocsReadProfile, root string) (model.RouteCanonicalLane, []string)
Tier1CanonicalRoute builds a canonical route from governance/profile alone. It does not require a full docs index — it derives the route skeleton from the read-model and the root docs that exist on the filesystem. This implements the fail-closed canonical semantics for RF-QRY-014.
Types ¶
Click to show internal directories.
Click to hide internal directories.